@@ -47,8 +47,7 @@ sub new {
 
 sub build_query {
     my $param = shift or return '';
-    my $opt   = { encode_reserved => 1 };
-    join '&', map {uri_encode($_, $opt) . '=' . uri_encode($param->{$_}, $opt)} sort keys %$param;
+    join '&', map {uri_encode($_) . '=' . uri_encode($param->{$_})} sort keys %$param;
 }
 
 sub build_request {
@@ -70,7 +69,7 @@ sub build_request {
     } else {
         $request->method('GET');
     }
-
+    
     return $request;
 }
 
@@ -146,10 +145,6 @@ Jeff Ober L<mailto:jeffober@gmail.com>
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+BSD license
 
 =cut
